@@ -63,6 +63,14 @@ $( document ).ready(function() {
             return false;
         }
     });
+    $('div.formbar-form input.email').keypress(function(key) {
+        /* Only allow a-z0-9-_@. (48-58 and "-") */
+        var cc = key.charCode;
+        console.log(cc)
+        if ((cc < 97 || cc > 122) && (cc < 48 || cc > 57) && cc != 0 && cc != 45 && cc != 64 && cc != 95 && cc != 46){
+            return false;
+        }
+    });
 
 
     /*
@@ -86,7 +94,6 @@ function evaluate(element) {
     for (var j = 0; j <= tokens.length - 1; j++) {
         var tfield = null;
         var value = null;
-        var readonly = null;
         if (tokens[j].indexOf("$") >= 0) {
             tfield = tokens[j].replace('$', '');
             // Select field
@@ -95,26 +102,17 @@ function evaluate(element) {
                           + 'div[name='+tfield+'], '
                           + 'textarea[name='+tfield+']');
             value = field.val();
-            readonly = field.attr("class");
-            if (readonly && readonly.indexOf("readonly") >= 0) {
-                readonly = true;
-            } else {
-                readonly = false;
-            }
             // If we can not get a value from an input fields the field my
             // be readonly. So get the value from the readonly element.
             // First try to get the unexpaned value, if there is no
             // value get the textvalue of the field. (Which is usually
             // the expanded value).
-            if (readonly) {
-                if (!value) {
-                    value = field.attr("value");
-                }
-                if (!value) {
-                    value = field.text();
-                }
+            if (!value) {
+                value = field.attr("value");
+            }
+            if (!value) {
+                value = field.text();
             }
-            value = value.trim();
             if (value.indexOf("[") < 0) {
                 if (!value) {
                     value = "None";
